import React, { useState } from 'react'
import ProjectSkillCard from './ProjectSkillCard'
import { projectsTypes, technologies } from '@/types/types'
import {CalendarDays, Eye} from 'lucide-react'
import moment from 'moment'
import Link  from 'next/link'
import default_image from '@/assets/default.jpeg'
import { convertNumberToAbbreviation } from '@/utils/number-format'
import { SERVER_ADDRESS } from '@/utils/address'
type Props = {
  project: projectsTypes
}

const ProjectCard = ({project}: Props) => {
  const frontends: technologies[] = []
  const backends: technologies[] = []

  const project_bg_image = project.image ? <div style={{backgroundImage: `url('${SERVER_ADDRESS + project.image.filePath}')`}} className="h-40 flex bg-cover bg-no-repeat bg-center"></div> :
  <div style={{backgroundImage: `url(${default_image.src})`}} className="h-40 flex bg-cover bg-no-repeat bg-center"></div>
  
  const project_technos = (technlogy: technologies[]) => {
    technlogy.map(techno_obj => {
      if (techno_obj.type === 'frontend') {
        frontends.push(techno_obj)
        
      } else if (techno_obj.type === 'backend') {
        backends.push(techno_obj)
      }
    })
  }

  project_technos(project.technologies)
  return (
    <Link href={`/projects/${project.id}`}>
      <div className="border rounded-md text-gray-500">
        {project_bg_image}
        <div className="space-y-3 p-4">
          <div className="flex justify-between items-center">
            <p className="font-ubuntu font-medium text-xl">{project.name}</p>
            <p className='flex space-x-1'><Eye /> <span>{convertNumberToAbbreviation(project.visitorsCount)}</span></p>
          </div>
          <p className="text-sm flex space-x-1 items-center"> <CalendarDays height={18} /> <span>{moment(project.createdAt).format('LL')}</span></p>
          <div className="flex justify-around">
            <ProjectSkillCard title="Front End" technologies={frontends} />
            <ProjectSkillCard title="Backend End" technologies={backends} />
          </div>
        </div>
      </div>
    </Link>
  )
}

export default ProjectCard