import Link from 'next/link'
import React, { useEffect, useState } from 'react'
import Logo from '@/assets/logo.png'
import Image from 'next/image'
import axios from '@/config/axios'
import { convertNumberToAbbreviation } from '@/utils/number-format'
import { useAuthContext } from '@/context/AuthContext'
import { deleteCookie } from 'cookies-next'
import { useRouter } from 'next/router'
import { LogOut } from 'lucide-react'

type Props = {}

const Navbar = (props: Props) => {
  const router = useRouter()
  const {user} = useAuthContext()
  const [visitors, set_visitors] = useState<number>(0)
  const get_visitors_count = () => {
    axios.get('/visitors')
      .then(response => {
        set_visitors(response.data['hydra:totalItems'])
      })
      .catch(err => {
        
      })
  }
  useEffect(() => {
    get_visitors_count()
  }, [])
  const logoutHandler = () => {
    deleteCookie('token')
    router.push('/')
  }
  return (
    <nav id="nav" className='bg-[crimson] text-white py-5'>
      <div className="w-11/12 mx-auto">
        <div className="flex items-center justify-between">
          <Link title="home" className="text-2xl" href='/'>
            <Image style={{width: 'auto'}} className="h-5" src={Logo} alt="logo" />
          </Link>
          <p>{convertNumberToAbbreviation(visitors)} <span className="md:hidden">Visitors</span> <span className="hidden md:inline">people visited my portfolio</span></p>
          <ul className='flex space-x-5 capitalize'>
              <li><Link title="home" href="/" >home</Link></li>
              <li><Link title="projects" href="/projects" className="">projects</Link></li>
              { user && <li><Link title="projects" href="/dashboard" className="">dashboard</Link></li>}
              { user && <button onClick={logoutHandler}><LogOut/></button>}
          </ul>
        </div>
      </div>
    </nav>
  )
}

export default Navbar