import { technologies } from '@/types/types'
import React, { useState } from 'react'
import { TableBody, Table, TableCell, TableHead, TableHeader, TableRow } from '../ui/table'
import Image from 'next/image'
import { FileEdit, XCircle } from 'lucide-react'
import { Switch } from '../ui/switch'
import default_image from '@/assets/default.jpeg'
import ReactPaginate from 'react-paginate'
import { SERVER_ADDRESS } from '@/utils/address'


type Props = {
  head: string[],
  more_to_load: boolean,
  techs: technologies[],
  handle_selected_techno: (tech: technologies) => void,
  update_status: (id: number, value: boolean) => void,
  delete_technology: (id: number) => void
}

const FrontendsTable = ({
    head, 
    techs, 
    update_status, 
    handle_selected_techno, 
    delete_technology,
    more_to_load
  }: Props) => {
  const itemsPerPage = 8
  const [itemOffset, setItemOffset] = useState(0)
  const endOffset = itemOffset + itemsPerPage
  const currentItems = techs.slice(itemOffset, endOffset);
  const pageCount = Math.ceil(techs.length / itemsPerPage);

  const handlePageClick = (event: any) => {
    const newOffset = (event.selected * itemsPerPage) % techs.length;
    setItemOffset(newOffset)
  }
  const handle_delete_technology = (id: number) => {
    const del = confirm('Voulez-vous supprimer?')
    if (del) {
      delete_technology(id)     
    }
  }

  const handle_status_update = (id: number, value: boolean) => {
    update_status(id, value)
  }

  const table_head = head.map((h, index) => (
    <TableHead key={index} className="text-center capitalize font-semibold">{h}</TableHead>
  ))
  const projects_row = currentItems.map((tech, index) => (
    <TableRow key={index}>
      <TableCell className="text-center">{index + 1}</TableCell>
      <TableCell className="text-center">{tech.name}</TableCell>
      <TableCell className="flex justify-center">
        {tech.logo ? <Image alt={tech.name} src={SERVER_ADDRESS + tech.logo.filePath } height={60} width={60} />:
        <Image alt={tech.name} src={default_image.src} height={30} width={60} />}
      </TableCell>
      <TableCell className="text-center">{tech.projects.length}</TableCell>
      <TableCell className="text-center">{tech.type}</TableCell>
      <TableCell className="flex justify-center">{<Switch defaultChecked={tech.status} onClick={() => handle_status_update(tech.id, tech.status)} />}</TableCell>
      <TableCell className="">
        <div className="flex space-x-3 justify-center">
          <span className='cursor-pointer' onClick={() => handle_selected_techno(tech)}>
            <FileEdit className='text-yellow-400 hover:scale-125 ease-in' />
          </span>
          <span className='cursor-pointer'>
            <XCircle onClick={() => handle_delete_technology(tech.id)} className='text-red-500 hover:scale-125 ease-in' />
          </span>
        </div>
      </TableCell>
    </TableRow>
  ))
  return (
    <>
      <Table>
        <TableHeader>
          <TableRow>
            {table_head}
          </TableRow>
        </TableHeader>
        <TableBody>
          {projects_row}
        </TableBody>
      </Table>
      
      <ReactPaginate
        breakLabel="..."
        nextLabel="next >"
        onPageChange={handlePageClick}
        pageRangeDisplayed={5}
        pageCount={pageCount}
        previousLabel="< previous"
        renderOnZeroPageCount={null}
        containerClassName="flex items-center space-x-3 my-5"
        pageLinkClassName="p-1 px-2 rounded-md text-[crimson]"
        activeClassName="flex bg-[crimson] justify-center items-center bg-white text-[crimson] border-[crimson] border"
      />
    </>
  )
}

export default FrontendsTable