import { getCookie } from 'cookies-next'
import { Loader, Terminal } from 'lucide-react'
import { useRouter } from 'next/router'
import React, {ReactNode, createContext, useContext, useEffect, useState} from 'react'
import Logo from '@/assets/logo.png'
import Image from 'next/image'
type Props = {
  children: ReactNode
}
export const AuthContext = createContext({
  user: false
})
export const useAuthContext = () => useContext(AuthContext)


export const AuthContextProvider = ({children}: Props) => {
  const router = useRouter()
  const [user, setUser] = useState(true)
  const [loading, setLoading] = useState(true)

  useEffect(() => {
    if(getCookie('token')){
      setUser(true)
      setLoading(false)
    } else {
      router.push('/')
    }
  }, [router])
  return (
    <AuthContext.Provider value={{user}}>
      {loading ? <div className="fixed inset-0 flex flex-col gap-2 items-center justify-center">
          <Loader className="animate-spin" />
          <div className="flex items-center gap-1">
            <Image alt='logo' src={Logo.src} height={30} width={40} />
            <span className="font-semibold text-lg"> PortFolio</span>
          </div>
        </div> :
        children}
    </AuthContext.Provider>
  )
}

export const HomeAuthContextProvider = ({children}: Props) => {
  const [user, setUser] = useState(false)
  useEffect(() => {
    if(getCookie('token')){
      setUser(true)
    }
  }, [])
  return (
    <AuthContext.Provider value={{user}}>
      {children}
    </AuthContext.Provider>
  )
}