import * as zod from 'zod'

const MAX_FILE_SIZE = 500000;
const ACCEPTED_IMAGE_TYPES = ["image/jpeg", "image/jpg", "image/png", "image/webp"];

const Project = zod.object({
  name: zod.string().min(2),
  date: zod.date(),
  frontends: zod.array(zod.number()),
  backends: zod.array(zod.number()),
  description: zod.string(),
  image: zod
  .any()
  .refine((files) => files?.length == 1, "Image is required.")
  .refine((files) => files?.[0]?.size <= MAX_FILE_SIZE, `Max file size is 5MB.`)
  .refine(
    (files) => ACCEPTED_IMAGE_TYPES.includes(files?.[0]?.type),
    ".jpg, .jpeg, .png and .webp files are accepted."
  ),
  url: zod.string().url(),
})

export default Project