import AdminBreadcrum from '@/components/AdminBreadcrum'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { Skeleton } from '@/components/ui/skeleton'
import axios from '@/config/axios'
import { post } from '@/config/axiosFunctions'
import { AxiosError } from 'axios'
import { CREATED, OK } from 'http-status'
import { ApiError } from 'next/dist/server/api-utils'
import React, { useEffect, useState } from 'react'
import { toast } from 'react-toastify'
import { Page, Text, View, Document, StyleSheet } from '@react-pdf/renderer'

const styles = StyleSheet.create({
  page: {
    flexDirection: 'row',
    backgroundColor: '#E4E4E4'
  },
  section: {
    margin: 10,
    padding: 10,
    flexGrow: 1
  }
});

type Props = {}

const Cv = (props: Props) => {
  const [file, set_file] = useState<File>()
  const [is_submit, set_is_submit] = useState(false)
  const [cv_name, set_cv_name] = useState<string>("")
  const [cv_url, set_cv_url] = useState<string>("")
  const [cvs, set_cvs] = useState<{name: string, file: {fileName: string, filePath: string}}[]>([])

  useEffect(() => { get_cv()}, [])
  const get_cv = () => {
    axios.get('/cvs')
      .then(response => {
        set_cvs(response.data['hydra:member'])
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
        set_is_submit(false)
      })
  }
  const handle_submit = async (e: React.FormEvent) => {
    e.preventDefault()
    set_is_submit(true)
    const form_data = new FormData()
    form_data.append('cv', file as Blob)

    let request_body: {name: string, file?: string} = {
      name: cv_name,
    }

    if(file){
      const file_uri = await upload_image(file)
      request_body = {...request_body, file: file_uri}
    }
    try {
      const response = await post('/cvs', request_body)
      if (response.status === OK) {
        toast.success('Cv added')
        set_is_submit(false)
        set_file(undefined)
        get_cv()
      }
    } catch (err: any) {
      toast.error(err.response?.statusText)
    }
  }

  const upload_image = async (file: File): Promise<string> => {
    let img_uri = ''
    const form_data = new FormData()
    form_data.append('file', file)
    const response = await axios.post('/mediaObjects', form_data, { headers: {'content-type': 'multipart/form-data'} })
    if (response.status === CREATED) {
      img_uri = response.data['@id']
    } else {
      set_is_submit(true)
      toast.error('An error occured while uploading image')
    }
    return img_uri
  }

  return (
    <DashboardLayout>
      <div className="w-11/12 mx-auto">
        <AdminBreadcrum label='Cv' ></AdminBreadcrum>
      </div>
      <section className=''>
        <div className="w-11/12 mx-auto">
          <div className="">
            <form onSubmit={handle_submit} className="p-1 space-x-3 flex items-center">
              <div className="">
                <Input placeholder='name' onChange={(e) => set_cv_name(e.target.value)} value={cv_name} className='border-gray-500' />
              </div>
              <div className="">
                <Input type='file' accept='.pdf' required onChange={(e) => set_file(e.target.files?.[0])} />
              </div>
              <Button disabled={is_submit} type='submit' className='bg-black mt-0 text-white'>Save</Button>
            </form>
          </div>
        </div>
      </section>
      <section className=''>
        <div className="w-11/12 mx-auto">
          <div className="py-4">
            <ul>
              {cvs.length > 0 ? cvs.map((cv, index) => (
                <li key={index}>{cv.name}</li>
              )) 
                :
                <li>No CV available</li>
              }
            </ul>
          </div>
          <div className="">
            <Skeleton className="lg:w-1/2 h-96 bg-gray-200" />
          </div>
          <div className="">
            <Document>
              <Page size="A4" style={styles.page}>
                <View style={styles.section}>
                  <Text>Section #1</Text>
                </View>
                <View style={styles.section}>
                  <Text>Section #2</Text>
                </View>
              </Page>
            </Document>
          </div>
        </div>
      </section>
    </DashboardLayout>
  )
}

export default Cv