import AdminBreadcrum from '@/components/AdminBreadcrum'
import DashboardCard from '@/components/DashboardCard'
import DashboardLayout from '@/components/layout/DashboardLayout'
import React, { useEffect, useState } from 'react'
import { Briefcase, Palette, Code2, Users2 } from 'lucide-react'
import axios from '@/config/axios'
import { stats } from '@/types/types'
import LineChart from '@/components/charts/BarChart'
import { toast } from 'react-toastify'
import { AxiosError } from 'axios'
import { get } from '@/config/axiosFunctions'
type Props = {}

const Index = (props: Props) => {
  const [stats, set_stats] = useState<stats | null>(null)
  const [projects, set_projects] = useState<number>(0)
  const [visitors, set_visitors] = useState<number>(0)
  const [technologies, set_technologies] = useState<number>(0)
  useEffect(() => {
    get_projects()
    get_technologies()
    get_visitors()
  }, [])
  const get_projects = async () => {
    await get('/admin/projects')
      .then(response => {
        set_projects(response.data["hydra:totalItems"])
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
      })
  }  
  const get_technologies = async () => {
    await get('/admin/technologies')
      .then(response => {
        set_technologies(response.data["hydra:totalItems"])
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
      })
  }
  const get_visitors = async () => {
    await get('/visitors')
      .then(response => {
        set_visitors(response.data["hydra:totalItems"])
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
      })
  }
  return (
    <DashboardLayout>
      <div className="w-11/12 mx-auto">
        <AdminBreadcrum label='Dashboard'></AdminBreadcrum>
        <section>
          <div className="grid lg:grid-cols-3 gap-3">
            <DashboardCard title='Project' count={projects} Icon={Briefcase} />
            <DashboardCard title='Technologies' count={technologies} Icon={Palette} />
            <DashboardCard title='Visitors' count={visitors} Icon={Users2} />
          </div>
          <div className="">
            <LineChart></LineChart>
          </div>
        </section>
      </div>
    </DashboardLayout>
  )
}

export default Index