import AdminBreadcrum from '@/components/AdminBreadcrum'
import ProjectTable from '@/components/table/ProjectTable'
import DashboardLayout from '@/components/layout/DashboardLayout'
import React, { useEffect, useState } from 'react'
import DescriptionModal from '@/components/modal/DescriptionModal'
import ProjectForm from '@/components/form/ProjectForm'
import { projectsTypes } from '@/types/types'
import axios from '@/config/axios'
import { toast } from 'react-toastify'
import { AxiosError, AxiosResponse } from 'axios'
import { OK } from 'http-status'
import { patch } from '@/config/axiosFunctions'
type Props = {}
export const project_head = [
  '#',
  'name',
  'image',
  'description',
  'technologies',
  'visits',
  'status',
  'created at',
  'updated at',
  'actions',
]
const Projects = (props: Props) => {
  const [show_description_modal, set_show_description_modal] = useState<boolean>(false)
  const [show_new_project_modal, set_show_new_project_modal] = useState<boolean>(false)
  const [description_text, set_description_text] = useState<string>('')
  const [projects, set_projects] = useState<projectsTypes[]>([])
  const [filtered_projects, set_filtered_projects] = useState<projectsTypes[]>([])
  const [selected_project, set_selected_project] = useState<projectsTypes | null>(null)
  const [search, set_search] = useState('')

  useEffect(() => {
    get_projects()
    }, [])
    
    const handle_description_modal = (text?: string) => {
      const description_text = text ? text : ''
    if(!show_description_modal){
      set_description_text(description_text)
      set_show_description_modal(true)
    } else {
      set_description_text('')
      set_show_description_modal(false)
    }
  }
  const get_projects = () => {
    axios.get('/admin/projects')
    .then(response => {
      set_projects(response.data['hydra:member'])
    })
    .catch((err: AxiosError) => {
      toast.error(err.message)
    })
  }
  const handle_project_modal = () => {
    set_show_new_project_modal(oldState => !oldState)
    get_projects()
    
  }
  const update_status = async (id: number, value: boolean) => {
    let status = value ? 0 : 1
    try {
      const response = await patch('/admin/projects/' + id, {status})
      if (response.status === OK) {
        toast.success('technology status updated')
      }
    } catch (err: any) {
      toast.error(err.response?.statusText)
    }
  }
  const handle_change_search = (search: string) => {
    set_search(search)
    const filter_projects = projects.filter(project => (
      project.name.toLowerCase().includes(search.toLowerCase())
    ))
    set_filtered_projects(filter_projects)
  }
  
  const handle_selected_project = (project: projectsTypes) => {
    set_selected_project(project)
    handle_project_modal()
  }
  const remove_selected_project = () => {
    set_selected_project(null)
  }
  return (
    <DashboardLayout>
      <div className="w-11/12 mx-auto">
        <AdminBreadcrum 
          handle_change_search={handle_change_search} 
          handle_open_new_form_modal={handle_project_modal} 
          label='Projects' 
          show_search 
          show_new_modal button_label='projects'
        />
      </div>
      <section className='w-11/12 mx-auto'>
        <ProjectTable update_status={update_status} 
          handle_selected_project={handle_selected_project} 
          show_desciption_modal={handle_description_modal} 
          projects={search === '' ? projects : filtered_projects} 
          head={project_head} />
        {
          show_description_modal && 
          <DescriptionModal 
            show_desciption_modal={handle_description_modal}  
            text={description_text} 
            />
        }
        {
          show_new_project_modal && 
          <ProjectForm 
          selected_project={selected_project} 
          remove_selected_project={remove_selected_project} 
          show_new_project_modal={handle_project_modal} 
          />
        }
      </section>
    </DashboardLayout>
  )
}

export default Projects