import AdminBreadcrum from '@/components/AdminBreadcrum'
import FrontendsTable from '@/components/table/FrontendsTable'
import DashboardLayout from '@/components/layout/DashboardLayout'
import React, { useEffect, useState } from 'react'
import TechnologyForm from '@/components/form/TechnologyForm'
import { technologies } from '@/types/types'
import axios from '@/config/axios'
import { AxiosError } from 'axios'
import { toast } from 'react-toastify'
import {get, patch} from '@/config/axiosFunctions'
import { OK } from 'http-status'
type Props = {}

export const project_head = [
  'id',
  'name',
  'logo',
  'project',
  'type',
  'status',
  'actions',
]
const Technologies = (props: Props) => {
  const [show_techno_modal, set_show_techno_modal] = useState<boolean>(false)
  const [selected_techno, set_selected_techno] = useState<technologies | null>(null)
  const [technologies, set_technologies] = useState<technologies[]>([])
  const [filtered_technologies, set_filtered_technolgies] = useState<technologies[]>([])
  const [search, set_search] = useState('')
  const [current_page, set_current_page] = useState<string>('/admin/technologies?page=1')
  const [next_page, set_next_page] = useState<string>('')
  const [more_to_load, set_more_to_load] = useState<boolean>(false)


  useEffect(() => {
    get_technologies()
  })
  
  const get_technologies = async () => {
    try {
      const response = await get(current_page)
      if (response.status === OK) {
        set_technologies(response.data['hydra:member'])
      }
    } catch (error: any) {
      toast.error(error.message)
    }
  }
  const update_status = async (id: number, value: boolean) => {
    let status = value ? 0 : 1
    try {
      const response = await patch('/admin/technologies/' + id, {status})
      if (response.status === OK) {
        toast.success('technology status updated')
      }
    } catch (err: any) {
      toast.error(err.response?.statusText)
    }
  }
  const delete_technology = (id: number) => {
    axios.delete('/dashboard/technology/delete/' + id)
    .then(response => {
      if(response.status === 200){
        get_technologies()
        toast.success('technology deleted')
      }
    })
    .catch((err: AxiosError) => {
      toast.error(err.response?.statusText)
    })
  }
  const handle_change_search = (search: string) => {
    set_search(search)
    const filter_technolgies = technologies.filter(technology => (
      technology.name.toLowerCase().includes(search.toLowerCase())
    ))
    set_filtered_technolgies(filter_technolgies)
  }
  const handle_techno_modal = () => {
    set_show_techno_modal(oldState => !oldState)
    get_technologies()
  }
  const remove_selected_techno = () => {
    set_selected_techno(null)
  }
  const handle_selected_techno = (tech: technologies) => {
    set_selected_techno(tech)
    handle_techno_modal()
  }
  return (
    <DashboardLayout>
      <div className="w-11/12 mx-auto">
        <AdminBreadcrum
          handle_open_new_form_modal={handle_techno_modal} 
          label='Technologies' 
          show_search show_new_modal 
          button_label='technologies' 
          handle_change_search={handle_change_search}
        />
      </div>
      <section className='w-11/12 mx-auto'>
        <FrontendsTable
          delete_technology={delete_technology}
          handle_selected_techno={handle_selected_techno}
          update_status={update_status}
          head={project_head}
          techs={search === '' ? technologies : filtered_technologies}
          more_to_load={more_to_load}
        />
        {
          show_techno_modal && 
          <TechnologyForm 
            remove_selected_techno={remove_selected_techno} 
            selected_tech={selected_techno} 
            handle_techno_modal={handle_techno_modal} 
          />
        }
      </section>
    </DashboardLayout>
  )
}

export default Technologies