import AdminBreadcrum from '@/components/AdminBreadcrum'
import DashboardLayout from '@/components/layout/DashboardLayout'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { get, patch } from '@/config/axiosFunctions'
import { Label } from '@radix-ui/react-label'
import { AxiosError } from 'axios'
import { OK } from 'http-status'
import React, { useEffect, useState } from 'react'
import { toast } from 'react-toastify'

type Props = {}

const User = (props: Props) => {
  const [username, set_username] = useState<string>('')
  const [password, set_password] = useState<string>('')
  const [confirm, set_confirm] = useState<string>('')
  const [is_submit, set_is_submit] = useState(false)

  useEffect(() => {
    get('/admin/users/2')
      .then(response => {
        set_username(response.data.email)
      })
      .catch((err: AxiosError) => {
        toast.error(err.response?.statusText)
      })
  }, [])

  const handle_submit = async (e: React.FormEvent) => {
    e.preventDefault()
    set_is_submit(true)
    const req_body = {
      username: username?.trim(),
      password: password?.trim(),
      confirm: confirm?.trim(),
    }
    
    if(req_body.confirm !== req_body.password) {
      set_is_submit(false)
      clear_form()
      return toast.error('password dont match')
    }
    try {
      const response = await patch('/users/2', req_body)
      if (response.status === OK) {
        toast.success('passwors updated')
        set_is_submit(false)
        clear_form()
      }
      
    } catch (error: any) {
      set_is_submit(false)
      toast.error(error.response?.statusText)
    }

  }
  const clear_form = () => {
    set_password('')
    set_confirm('')
    set_is_submit(false)
  }
  return (
    <DashboardLayout>
      <div className="w-11/12 mx-auto">
        <AdminBreadcrum label='User' ></AdminBreadcrum>
      </div>
      <section>
        <div className="w-11/12 mx-auto">
          <div className="">
            <form onSubmit={handle_submit} className="space-y-3">
              <div className="space-y-2">
                <Label>Username</Label>
                <Input value={username} type='text' onChange={(e) => set_username(e.target.value)} />
              </div>
              <div className="">
                <Label>Password</Label>
                <Input type='password' value={password} onChange={(e) => set_password(e.target.value)} />
              </div>
              <div className="">
                <Label>Confirm Password</Label>
                <Input type='password' value={confirm} onChange={(e) => set_confirm(e.target.value)} />
              </div>
              <Button disabled={is_submit} type='submit' className='w-full bg-black text-white'>Save</Button>
            </form>
          </div>
        </div>
      </section>
    </DashboardLayout>
  )
}

export default User