'use client'
import Image from 'next/image'
import DefaultLayout from '@/components/layout/default'
import Fr from '@/assets/fr.jpeg'
import En from '@/assets/en.png'
import Bg from '../assets/bg.jpg'
import SectionHead from '@/components/SectionHead'
import Picture from '@/assets/pic.jpeg'
import ReactTypedComponent from '@/components/ReactTyped'
import IconCard from '@/components/IconCard'
import { Database, Palette, Code2, AtSign, Phone, MapPin } from 'lucide-react'
import ProjectSkillCard from '@/components/ProjectSkillCard'
import axios from '@/config/axios'
import { useEffect, useState } from 'react'
import { technologies as technology_type } from '@/types/types'
import { saveAs} from 'file-saver'
import { toast } from 'react-toastify'
import { AxiosError } from 'axios'
import Head from 'next/head'
import { SERVER_ADDRESS } from '@/utils/address'

export default function Home() {
  const [frontends, set_frontends] = useState<technology_type[]>([])
  const [backends, set_backends] = useState<technology_type[]>([])
  const [mobiles, set_mobiles] = useState<technology_type[]>([])
  const [techno_type_count, set_techno_type_count] = useState<number>(3)
  const [cv_name, set_cv_name] = useState<string>('')
  const [cv_path, set_cv_path] = useState<string>('')

  const technology_type_count = 2
  const get_technologies = () => {
    const _frontends: technology_type[] = []
    const _backends: technology_type[] = []
    const _mobiles: technology_type[] = []
    
    axios.get('/technologies')
      .then(response => {
        response.data['hydra:member'].map((technology: technology_type) => {
          if(technology.type === 'frontend') {
            _frontends.push(technology)
          }
          if(technology.type === 'backend') {
            _backends.push(technology)
          }
          if(technology.type === 'mobile') {
            _mobiles.push(technology)
          }
        })
        set_frontends(_frontends)
        set_backends(_backends)
        set_mobiles(_mobiles)
        if(_mobiles.length > 0) {
          set_techno_type_count(4)
        }
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
      })
    axios.get('/cvs')
      .then(response => {
        set_cv_path(response.data['hydra:member'][0].file?.filePath)
        set_cv_name(response.data['hydra:member'][0].name)
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
      })
  }
  useEffect(() => {
    get_technologies()
  }, [])
  const saveFile = () => {
    saveAs(
      SERVER_ADDRESS + cv_path,
      "cv.pdf"
    );
  };
  return (
    <DefaultLayout>
      <Head>
        <title>Portfolio</title>
        <meta
          name="description"
          content="Some project that I have been working through"
        />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link rel="icon" href="/logo.png" />
      </Head>
      <section style={{backgroundImage: `url(${Bg.src})`}} className={`h-screen bg-no-repeat bg-center bg-cover text-white`}>
        <div className="h-4/6 w-10/12 mx-auto">
          <div className="h-full flex items-center">
            <div className="space-y-2">
              <p className="text-3xl font-ubuntu">Hi My name is</p>
              <p className="text-5xl font-ubuntu">Schuame Alexandre Lionel</p>
              <p className="text-3xl font-ubuntu">
                i am a
                <ReactTypedComponent/>
              </p>
            </div>
          </div>
        </div>
      </section>
      <section className="py-24">
        <div className="w-10/12 mx-auto">
          <SectionHead title="About Me" sub_title="who i am" />
          <div className="flex flex-wrap mt-10 justify-center md:justify-around gap-8">
            <Image className="w-72 h-72 lg:w-96 lg:h-96 rounded object-cover" src={Picture} alt="me" />
            <div className="w-[450px]">
              <p className="text-xl font-bold">I'm 
                <ReactTypedComponent/>
              </p>
              <p className="text-lg">
                I am a Full Stack Developer with a passion for creating innovative solutions. 
                I am excelling at managing complex projects. With expertise in both front end and back end development, I use the best 
                practices to drive impactful results. As a collaborative team with strong problem-solving skills, 
                I am committed to delivering exceptional code, meeting deadlines, and exceeding client expectations
              </p>
              <p className="flex mt-5">
                <a className="border-2 border-[crimson] text-[crimson] p-4 rounded-2xl font-medium hover:bg-[crimson] hover:text-white hover:border-[crimson] transition-all duration-75" href="mailto:contact@schuamealexandre.com">Contact Me</a>
                {/* <a href={SERVER_ADDRESS + cv_path} target='_blank' download='cv.png' className="bg-[crimson] cursor-pointer p-4 rounded-2xl text-white hover:bg-white hover:text-[crimson] hover:border-2 hover:border-[crimson] transition-all duration-75">Download Cv</a> */}
              </p>
            </div>
          </div>
        </div>
      </section>
      <section className="py-24 bg-black">
        <div className="w-10/12 mx-auto">
          <SectionHead title="My Services" sub_title="what i provide" dark/>
          <div className="grid md:grid-cols-3 gap-8 mt-5">
            <IconCard Icon={Database} title="App Design" description="I design your app using modern tools from your needs, ideas" />
            <IconCard Icon={Palette} title="Front End Dev" description="I build users interfaces based on your specifications" />
            <IconCard Icon={Code2} title="Back End Dev" description="I implement the logic based on the app design to manage the datas on your app" />
          </div>
        </div>
      </section>
      <section className="py-24">
        <div className="w-10/12 mx-auto">
          <SectionHead title="My Skills" sub_title="what i know"/>
          <div className={`grid gap-5 lg:grid-cols-${techno_type_count}`}>
            {frontends.length > 0 && <ProjectSkillCard title="Frontend" technologies={frontends}/> }
            {backends.length > 0 && <ProjectSkillCard title="Frontend" technologies={backends}/> }
            {mobiles.length > 0 && <ProjectSkillCard title="Mobile" technologies={mobiles}/> }
            <div className="mt-5 text-center space-y-5 px-4">
              <h3 className="font-medium font-ubuntu">Languages Spoken</h3>
              <div className="flex justify-center gap-5">
                <Image width={50} height={50} src={Fr} alt="france flag" />  
                <Image width={50} height={50} src={En} alt="great britain flag" /> 
              </div>
            </div>
          </div>
        </div>
      </section>
      <section className="py-24 bg-black">
        <div className="w-10/12 mx-auto">
          <SectionHead title="Contact Me" sub_title="get in touch" dark/>
          <div className="flex justify-center mt-5">
            <ul className="text-white space-y-5">
              <li className="space-x-2 flex">
                <AtSign className="text-[crimson] text-xl"/>
                <a href="mailto:contact@schuamealexandre.com" className="">contact@schuamealexandre.com</a>
              </li>
              <li className="space-x-2 flex">
                <Phone className="text-[crimson] text-xl" />
                <span>+237 695 254 870</span>
              </li>
              <li className="space-x-3 flex">
                <MapPin className="fa-solid fa-at text-[crimson] text-xl"/>
                <span>Douala, Cameroun</span>
              </li>
            </ul>
          </div>
        </div>
      </section>
    </DefaultLayout>
  )
}
