import AdminBreadcrum from '@/components/AdminBreadcrum'
import DefaultLayout from '@/components/layout/default'
import { Button } from '@/components/ui/button'
import { Input } from '@/components/ui/input'
import { Label } from '@radix-ui/react-label'
import { AxiosError } from 'axios'
import { OK } from 'http-status'
import React, { useEffect, useState } from 'react'
import { toast } from 'react-toastify'
import { useRouter } from 'next/router'
import {setCookie} from 'cookies-next'
import { post } from '@/config/axiosFunctions'


type Props = {}

const Login = (props: Props) => {
  const [username, set_username] = useState<string>('')
  const [password, set_password] = useState<string>('')
  const [is_submit, set_is_submit] = useState(false)
  const router = useRouter()


  const handle_submit = (e: React.FormEvent) => {
    e.preventDefault()
    set_is_submit(true)
    const req_body = {
      username: username?.trim(),
      password: password?.trim(),
    }
    if(req_body.password.length === 0) {
      set_is_submit(false)
      clear_form()
      return toast.error('provide a valid password')
    }
    post('/login_check', req_body)
      .then(response => {
        if (response.status === OK) {
          setCookie('token', response.data.token)
          router.push('/dashboard')
        }
      })
      .catch((err: AxiosError) => {
        toast.error(err.message)
        clear_form()
      })
      .finally(() => {
        clear_form()
      })
  }
  const clear_form = () => {
    set_password('')
    set_is_submit(false)
  }
  return (
    <DefaultLayout>
      
      <section className='h-[85vh]'>
        <div className="w-11/12 mx-auto">
          <div className="mt-10">
            <form onSubmit={handle_submit} className="space-y-3 lg:w-1/2 mx-auto">
              <div className="space-y-2">
                <Label>Username</Label>
                <Input required value={username} type='email' onChange={(e) => set_username(e.target.value)} />
              </div>
              <div className="">
                <Label>Password</Label>
                <Input required type='password' value={password} onChange={(e) => set_password(e.target.value)} />
              </div>
              <Button disabled={is_submit} type='submit' className='w-full bg-black text-white'>Save</Button>
            </form>
          </div>
        </div>
      </section>
    </DefaultLayout>
  )
}

export default Login