'use client'
import React, { useEffect, useState } from 'react'
import DefaultLayout from '@/components/layout/default'
import { ArrowRightToLine, CalendarDays, Eye, MousePointerClick } from 'lucide-react'
import { projectsTypes, technologies } from '@/types/types'
import axios from '@/config/axios'
import { useRouter } from 'next/router'
import ProjectDetail from '@/components/skeleton/ProjectDetail'
import moment from 'moment'
import default_image from '@/assets/default.jpeg'
import Link from 'next/link'
import ProjectSkillCard from '@/components/ProjectSkillCard'
import { convertNumberToAbbreviation } from '@/utils/number-format'
import Head from 'next/head'
import { toast } from 'react-toastify'
import { SERVER_ADDRESS } from '@/utils/address'
type Props = {}


const Index = (props: Props) => {
  const frontends: technologies[] = []
  const backends: technologies[] = []
  const router = useRouter()
  const id = router.query.id
  const [project, set_project] = useState<projectsTypes | null>(null)
  const [loading, setLoading] = useState(true)
  useEffect(() => {
    if (id !== undefined) {
      axios.get('/projects/'+ id)
        .then(response => {
          set_project(response.data)
        })
        .catch(err => {
          toast.error(err.response?.statusText)
        })
        setTimeout(() => {
          setLoading(false)
        }, 700)
    }
  }, [id])
  const project_bg_image = project?.image ? <div style={{backgroundImage: `url('${SERVER_ADDRESS + project.image.filePath}')`}} className="h-80 flex bg-cover bg-no-repeat bg-center"></div>
  : <div style={{backgroundImage: `url(${default_image.src})`}} className="h-80 flex bg-cover bg-no-repeat bg-center"></div>
  
  const project_technos = (technology: technologies[] | undefined) => {
    technology && technology.map(techno_obj => {
      if (techno_obj.type === 'frontend') {
        frontends.push(techno_obj)
        
      } else if (techno_obj.type === 'backend') {
        backends.push(techno_obj)
      }
    })
  }
  project_technos(project?.technologies)
  return (
    <DefaultLayout>
      <Head>
        <title>Portfolio | {project && project.name}</title>
        <meta
          name="description"
          content="List of projects that I have been working through"
        />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link rel="icon" href="/logo.png" />
      </Head>
      <div className="w-10/12 mx-auto min-h-screen">
        <div className="py-4">
          {
            loading && !project ?
            <ProjectDetail/> :
            <article>
              <div className="py-4 flex">
                <h1 className='text-5xl'>{project?.name}</h1>
              </div>
              {project && <Link target='_blank' href={project.url} passHref={true}>
                {project_bg_image}
              </Link>}
              <div className="text-gray-500 py-4 space-y-3">
                <div className='flex justify-between'>
                  <div className='flex'><CalendarDays height={20}/> <span>{moment(project?.createdAt).format('LL')}</span></div>
                  <p className='flex space-x-1' title='visitors'><Eye /> <span>{project && convertNumberToAbbreviation(project.visitorsCount)}</span></p>
                </div>
                <div className="flex justify-around">
                  <ProjectSkillCard title="Front End" technologies={frontends} />
                  <ProjectSkillCard title="Backend End" technologies={backends} />
                </div>
                <p>{project?.description}</p>
                <div>
                  {project && <Link target='_blank' passHref={true} href={project.url} className='flex space-x-2'>
                    <span>Go to the project</span> <span><ArrowRightToLine /></span>
                  </Link>}
                </div>
              </div>
            </article>
          }
        </div>
      </div>
    </DefaultLayout>
  )
}

export default Index