import React, {useEffect, useState} from 'react'
import DefaultLayout from '@/components/layout/default'
import ProjectCard from '@/components/ProjectCard'
import SectionHead from '@/components/SectionHead'
import Pagination from '@/components/Pagination'
import ProjectVisitorList from '@/components/skeleton/ProjectVisitorList'
import { projectsTypes } from '@/types/types'
import axios from '@/config/axios'
import Head from 'next/head'
import { get } from '@/config/axiosFunctions'
type Props = {}

const Index = (props: Props) => {
  const [projects, setProjects] = useState<projectsTypes[]>([])
  const [loading, setLoading] = useState(true)
  const [currentPage, setCurrentPage] = useState(1);
  const projectPerPage = 9;
  useEffect(() => {
    get('/projects')
      .then(response => {
        setProjects(response.data['hydra:member'])
      })
      .catch(err => {
        
      })
    setTimeout(() => {
      setLoading(false)
    }, 500)
  }, [])
  const indexOfLastProject = currentPage * projectPerPage;
  const indexOfFirstProject = indexOfLastProject - projectPerPage;
  const currentProjects = projects.slice(indexOfFirstProject, indexOfLastProject);

  const handlePageChange = (pageNumber: number) => {
    setCurrentPage(pageNumber);
  };
  const listedProject = currentProjects.map((project, index) => (
    <ProjectCard key={index} project={project} />
  ))
  return (
    <DefaultLayout>
      <Head>
        <title>Portfolio | Projects</title>
        <meta
          name="description"
          content="List of projects that I have been working through"
        />
        <meta name="viewport" content="width=device-width, initial-scale=1" />
        <link rel="icon" href="/logo.png" />
      </Head>
      <section className="min-h-screen py-16">
        <div className="w-10/12 mx-auto">
            <SectionHead title="My Projects" sub_title="what i did"/>
            {
              projects.length === 0 && !loading ? 
              <ProjectVisitorList/> :
              
              <div className="">
                <div className="mt-5 grid lg:grid-cols-3 gap-5">
                  { listedProject}
                </div>
                <Pagination
                  currentPage={currentPage}
                  totalPages={Math.ceil(projects.length / projectPerPage)}
                  onPageChange={handlePageChange}
                />
              </div> 
            }
        </div>
    </section>
    </DefaultLayout>
  )
}

export default Index